@@ -101,6 +101,7 @@ import zipfile
 import shutil
 import urllib.request, urllib.error, urllib.parse
 import requests
+from requests_toolbelt import MultipartEncoder
 
 class TLPClient():
     """
@@ -272,9 +273,10 @@ class TLPClient():
         url = "%s/%s/%s" % (self._api_base_url, self._api_type, interface)
         self.parameters['manifest'] = self.manifest
         if pkg != None:
-            files = {'json':('data.json', json.dumps(self.parameters), 'application/json')}
-            files['pkg'] = ('mp.zip', open(pkg, 'rb'), 'application/zip')
-            self._response = self._session.post(url=url,files=files, verify=False)
+            fields = {'json':('data.json', json.dumps(self.parameters), 'application/json')}
+            fields['pkg'] = ('mp.zip', open(pkg, 'rb'), 'application/zip')
+            encoder = MultipartEncoder(fields=fields)
+            self._response = self._session.post(url=url,data=encoder, headers={"Content-Type": encoder.content_type}, verify=False)
         else:
             self._response = self._session.post(url=url,data=json.dumps(self.parameters), headers={'Content-Type':'application/json'}, verify=False)
             
@@ -1258,22 +1260,45 @@ class TLPSpeechClient(TLPStandardClient):
             self.manifest['callback']['params'] = params
 
 
-    def api_list_fullinfo(self, limit=10, page=1, su=None):
+    def api_list_fullinfo(self, limit=10, page=1, external_id=None, 
+                                title=None, date_from=None, date_to=None,
+                                sort=None, su=None):
       """ Performs an API call to the /list_fullinfo interface:
 
 	  > *Get a list of all existing audios and videos in the TLP Database, plus
              their metadata, captions available, and media file locations. Objects are
              sorted by ingestion date, from the more recent to the oldest.*
 
+          Optionally, you can use **_external_id_** and **_title_** parameters
+          to filter out results. It will return those objects containing the
+          provided strings in the corresponding fields. E.g. `title =
+          "2022-1135177c"` will return all objects whose title contains the string 
+          `2022-1135177c`.
+
+          Also optionally, **_date_from_** and/or **_date_to_** can be used to
+          search for objects that were ingested to the platform in a specific time range.
+          Dates should be provided either in format `yyyy-mm-dd` or `dd-mm-yyyy`.
+
           Queries to this interface are limited to **_limit_** results. Use **_page_** > 1 
           to retrieve further results, if any. 
 
+          Resuts can be sorted according to the **_sort_** parameter. Allowed
+          values are: `title, title:asc, title:desc, external_id,
+          external_id:asc, external_id:desc, date, date:asc,
+          date:desc`.  By default, elements are sorted in descendant order,
+          by their internal ID.
+
 	  The **_su_** (*substitute user*) option can be used by Admin users
           to be identified as another existing API user at the TLP API.
       """
       self._reset()
       self.parameters['limit'] = limit
       self.parameters['page'] = page
+      if external_id != None: self.parameters['external_id'] = external_id
+      if title != None: self.parameters['title'] = title
+      if date_from != None: self.parameters['date_from'] = date_from
+      if date_to != None: self.parameters['date_to'] = date_to
+      if sort != None: self.parameters['sort'] = sort
       if su != None: self.parameters['su'] = su
       self._set_auth_parameters_secret_key()
       self._call("list_fullinfo")
